Modify maximum timeout value (60 -> 3600)
authorsung.goo.kim <sung.goo.kim@samsung.com>
Fri, 8 Jan 2016 00:14:31 +0000 (09:14 +0900)
committerYoungjae Shin <yj99.shin@samsung.com>
Mon, 11 Jan 2016 00:27:00 +0000 (09:27 +0900)
Change-Id: I2944e94df3d876e30aebd5c8b135f4b4e05f9672

lib/icl-dbus.h
lib/icl.c
lib/include/iotcon.h

index 9260d96..5c9da41 100644 (file)
@@ -21,7 +21,7 @@
 #include "ic-dbus.h"
 
 #define ICL_DBUS_TIMEOUT_DEFAULT 30 /* 30 sec */
-#define ICL_DBUS_TIMEOUT_MAX 60 /* 60 sec */
+#define ICL_DBUS_TIMEOUT_MAX 60*60 /* 60 min */
 
 
 icDbus* icl_dbus_get_object();
index f079a86..3a9d020 100644 (file)
--- a/lib/icl.c
+++ b/lib/icl.c
@@ -55,7 +55,7 @@ API int iotcon_set_timeout(int timeout_seconds)
        int ret;
 
        if (ICL_DBUS_TIMEOUT_MAX < timeout_seconds || timeout_seconds <= 0) {
-               ERR("timeout_seconds(%d) must be in range from 1 to 60", timeout_seconds);
+               ERR("timeout_seconds(%d) must be in range from 1 to 3600", timeout_seconds);
                return IOTCON_ERROR_INVALID_PARAMETER;
        }
 
index 73aa6da..6fbe785 100644 (file)
@@ -102,7 +102,7 @@ int iotcon_get_timeout(int *timeout_seconds);
  *
  * @since_tizen 3.0
  *
* @param[in] timeout_seconds Seconds for timeout (must be in range from 1 to 60)
  *
  * @return 0 on success, otherwise a negative error value.
  * @retval #IOTCON_ERROR_NONE Successful
@@ -102,7 +102,7 @@ int iotcon_get_timeout(int *timeout_seconds);
  * @since_tizen 3.0
  *
- * @param[in] timeout_seconds Seconds for timeout (must be in range from 1 to 60)
+ * @param[in] timeout_seconds Seconds for timeout (must be in range from 1 to 3600)
  *
  * @return 0 on success, otherwise a negative error value.